application/link_builder/link_builder_factory library
Classes
- LinkBuilderFactory
-
The
LinkBuilderFactoryclass is responsible for creating link builders based on the type of the app.
LinkBuilderFactory class is responsible for creating link builders based on the type of the app.